@@ -2,6 +2,7 @@
 
 from jsondaora.dataclasses import asdataclass
 from jsondaora.decorator import jsondaora
+from jsondaora.exceptions import DeserializationError
 from jsondaora.schema import (
     IntegerField,
     StringField,
@@ -13,7 +14,7 @@ from jsondaora.serializers import dataclass_asjson, typed_dict_asjson
 from jsondaora.typed_dict import as_typed_dict, as_typed_dict_field
 
 
-__version__ = '0.12.2'
+__version__ = '0.13.1'
 
 
 __all__ = [
@@ -28,4 +29,5 @@ __all__ = [
     'integer',
     'string',
     'jsonschema_asdataclass',
+    'DeserializationError',
 ]
